@@ -4,6 +4,7 @@ import pandas as pd
 import copy
 from tqdm import tqdm
 import anndata
+import swan_vis
 from swan_vis.utils import *
 
 # super class that both SwanGraph and PlottedGraph inherit from.
@@ -17,10 +18,14 @@ class Graph:
 		----------
 		datasets (list of str):
 			Names of datasets in the Graph
+		gene_datasets (list of str):
+			Names of datasets w/ gene expression in the Graph
 		annotation (bool):
 			Whether an annotation transcriptome has been added.
 		abundance (bool):
 			Whether abundance data has been added to the SwanGraph
+		gene_abundance (bool):
+			Whether gene abundance data has been added to the SwanGraph
 		loc_df (pandas DataFrame):
 			DataFrame of all unique observed genomic
 			coordinates in the transcriptome
@@ -33,8 +38,12 @@ class Graph:
 		adata (anndata AnnData):
 			Annotated data object to hold transcript expression values
 			and metadata
+		gene_adata (anndata AnnData):
+			Annotated data object to hold gene expression values / metadata
 		edge_adata (anndata AnnData):
 			Annotated data object to hold edge expression values and metadata
+		ic_adata (anndata AnnData):
+			Annotated data object to hold intron chain expression values / metadata
 		tss_adata (anndata AnnData):
 			Annotated data object to hold TSS expression values and metadata
 		tes_adata (anndata AnnData):
@@ -42,8 +51,10 @@ class Graph:
 		"""
 
 		self.datasets = []
+		self.gene_datasets = []
 		self.annotation = False
 		self.abundance = False
+		self.gene_abundance = False
 		self.loc_df = pd.DataFrame(columns=['chrom', 'coord',
 									   'vertex_id'])
 		self.edge_df = pd.DataFrame(columns=['v1', 'v2', 'strand',
@@ -53,6 +64,8 @@ class Graph:
 
 		# adata objects for transcripts, edges, locations, tss, and tes
 		self.adata = anndata.AnnData()
+		self.gene_adata = anndata.AnnData()
+		self.ic_adata = anndata.AnnData()
 		self.edge_adata = anndata.AnnData()
 		self.tss_adata = anndata.AnnData()
 		self.tes_adata = anndata.AnnData()
@@ -61,6 +74,23 @@ class Graph:
 	################# Related to checking contents of Graph ##################
 	##########################################################################
 
+	def get_adatas(self):
+		"""
+		Get a list of populated AnnData objects in the graph
+
+		Returns:
+			adatas (list of anndata AnnData): List of AnnData objects
+		 			in the SwanGraph that have data
+		"""
+		check_adatas = [self.adata, self.gene_adata,
+				        self.tss_adata, self.tes_adata,
+						self.ic_adata]
+		adatas = []
+		for adata in check_adatas:
+			if not adata.obs.empty:
+				adatas.append(adata)
+		return adatas
+
 	# check that input datasets are in the Graph:
 	def check_datasets(self, datasets):
 		"""
@@ -362,6 +392,12 @@ class Graph:
 		"""
 		return self.abundance
 
+	def has_gene_abundance(self):
+		"""
+		Checks if gene abundance data has been added to the Graph.
+		"""
+		return self.gene_abundance
+
 	##########################################################################
 	############################# Accessing data ############################
 	##########################################################################
@@ -435,6 +471,17 @@ class Graph:
 			vertex = self.t_df.loc[(self.t_df.gid == gid)].path.tolist()[0][0]
 		return self.edge_df.loc[vertex, 'strand']
 
+	def get_chrom_from_gid(self, gid):
+		"""
+		Return the chromosome of the input gene ID.
+
+		Parameters:
+			gid (str): Gene ID
+		"""
+		chrom = self.loc_df.loc[self.t_df.loc[self.t_df.gid==gid,
+					'loc_path'].tolist()[0][0], 'chrom']
+		return chrom
+
 	def get_path_from_tid(self, tid):
 		"""
 		Return the edge path of the input transcript ID.
