@@ -162,6 +162,7 @@ class PlottedGraph(Graph):
 
 		self.g_min, self.g_max = self.get_gene_min_max(gid)
 		self.strand = self.get_strand_from_gid(gid)
+		self.chrom = self.get_chrom_from_gid(gid)
 
 		# get positions and sizes of nodes/edges in this gene
 		self.new_swangraph()
@@ -434,6 +435,257 @@ class PlottedGraph(Graph):
 	######################## Browser track style plotting #########################
 	###############################################################################
 
+
+	def plot_line_bw_regions(self, regions, scale, strand, x, y, h, color, ax,
+							 linewidth=1):
+	    """
+	    Plot a line connecting two regions
+
+	    Parameters:
+	        regions (list of tuple of int): Start and end regions
+	        strand (str): {'+', '-'}
+	        x (float): x offset
+	        y (float): y position
+	        h (float): height of vertical bars
+	        color (str): Color to plot
+	        ax (matplotlib axes): Axis to plot on
+
+	    Returns:
+	        ax (matplotlib axes): Axis w/ line plotted b/w 2 regions
+	    """
+
+	    g_min = self.g_min
+	    g_max = self.g_max
+
+	    coords = [regions[0][0], regions[0][1], regions[1][0], regions[1][1]]
+	    coords.sort()
+	    min_coord = coords[1]
+	    max_coord = coords[2]
+	    coord_dist = max_coord-min_coord
+
+	    dist = 75*scale
+	    y_line = y + (h/2)
+	    if strand == '+':
+	        c1 = ((min_coord-g_min)*scale)+x
+	        c2 = c1+(coord_dist*scale)
+	        x_coords = [c1+dist, c2-dist]
+	    elif strand == '-':
+	        c1 = ((g_max-max_coord)*scale)+x
+	        c2 = c1+(coord_dist*scale)
+	        x_coords = [c1+dist, c2-dist]
+
+	    # linewidth = h*(2/0.2)
+	    plt.plot(x_coords, [y_line,y_line], color=color, linewidth=linewidth)
+
+	    return ax
+
+	def plot_scale(self, x, y, h, fontsize, ax, **kwargs):
+	    """
+	    Plot a scale for a plotted region
+
+	    Parameters:
+	        x (float): x offset
+	        y (float): y position
+	        h (float): height of vertical bars
+	        fontsize (float): Size of font to display on scale
+	        ax (matplotlib axes): Axis to plot on
+
+	    Returns:
+	        ax (matplotlib axes): Axis w/ line plotted b/w 2 regions
+	    """
+
+	    # get plot limits
+	    g_min = self.g_min
+	    g_max = self.g_max
+	    gene_len = g_max - g_min
+	    width = int((10/10000)*gene_len)
+	    scale = self.scale
+	    strand = self.strand
+
+	    # try different scale lengths until we've reached something optimal
+	    scale_len = 500
+	    while 1:
+	        if scale_len >= gene_len:
+	            break
+	        scale_len *= 10
+
+	    # dial it back so we show a nice chunk instead of the scale of the entire gene
+	    scale_len /= 10
+
+	    # are we going to indicate this in bp, kb, mb?
+	    if scale_len < 1000:
+	        scale_unit = 'bp'
+	        text_scale = scale_len
+	    elif scale_len < 10**6:
+	        scale_unit = 'kb'
+	        text_scale =  scale_len / 1000
+	    else:
+	        scale_unit = 'mb'
+	        text_scale = scale_len / 10**6
+	    text_scale = int(text_scale)
+
+	    # turn the boundaries of the scale into regions
+	    g_ave = (g_max+g_min)/2
+	    scale_min = g_ave - (scale_len/2)
+	    scale_max = g_ave + (scale_len/2)
+	    dist = int((50/10000)*gene_len)
+	    regions = [(scale_min-dist, scale_min),
+	               (scale_max, scale_max+dist)]
+
+	    # regions on either side of the scale and the line
+	    ax = self.plot_regions(regions, scale, strand, g_min, g_max, x, y, h, 'k', ax)
+	    ax = self.plot_line_bw_regions(regions, scale, strand, x, y, h, 'k', ax, **kwargs)
+
+	    # text
+	    coords = [regions[0][0], regions[0][1], regions[1][0], regions[1][1]]
+	    coords.sort()
+	    dist = 200*scale
+	    if strand == '+':
+	        coord = coords[0]
+	        coord = ((coord-g_min)*scale)+x-dist
+	    elif strand == '-':
+	        coord = coords[-1]
+	        coord = ((g_max-coord)*scale)+x-dist
+	    txt = '{} {}'.format(text_scale, scale_unit)
+	    y = y+(h/2)
+	    ax.text(coord, y, txt, fontsize=fontsize, horizontalalignment='right', verticalalignment='center')
+
+	    return ax
+
+	def plot_regions(self, regions, scale, strand, plot_min, plot_max,
+					 x, y, h, color, ax,
+					 verbose=False):
+		"""
+		Plot exons of a gene, bed regions, etc.
+
+		Parameters:
+			regions (list of tuple of int): Coords for start and end of each
+				region to plot
+			scale (float): Scale of plot
+			plot_min (int): Min genomic coord plotted
+			plot_max (int): Max genomic coord plotted
+			x (float): X postition of leftmost region to plot
+			y (float): Y position of plotted regions
+			h (float): Height of plotted regions
+			color (str or list of str): Color to plot each region in
+			ax (matplotlib axes): Matplotlib axes to make plot on
+
+		Returns:
+			ax (matplotlib axes): Matplotlib axes with blocks plotted
+		"""
+		if type(color) == list:
+			colors = color
+		else:
+			colors = [color for i in range(len(regions))]
+
+		y_coord = y
+		i = 0
+		for v1,v2 in regions:
+
+			# color
+			color = colors[i]
+
+			# get coords from loc_df
+			min_coord = min(v1, v2)
+			max_coord = max(v1, v2)
+
+			# depending on strand, get starting coord and witdh of exon
+			if strand == '+':
+				x_coord = ((min_coord-plot_min)*scale)+x
+			elif strand == '-':
+				x_coord = ((plot_max-max_coord)*scale)+x
+
+			# width
+			width = (max_coord-min_coord)*scale
+
+			if verbose:
+				print(min_coord)
+				print(max_coord)
+				print('x_coord:{}'.format(x_coord))
+				print('width : {}'.format(width))
+				print()
+
+			# plot
+			rect = pch.Rectangle((x_coord, y_coord), width, h, color=color,
+			                     edgecolor=None, linewidth=0)
+			ax.add_patch(rect)
+
+			i+=1
+		return ax
+
+	def plot_browser(self, x=0, y=0, w=14, h=0.1,
+					 color=None, linewidth=3,
+					 ax=None, **kwargs):
+		"""
+		Plot the browser representation for one transcript on a given axis
+
+		Parameters:
+			x (float): Start x coord from right of browser model
+			y (float): Start y coord from bottom right corner of browser model
+			w (float): Maximum width of browser model
+			h (float): Height of browser model
+			linewidth (float): Width of intron line
+			color (str): Color to plot model in
+			ax (matplotlib axes): Axes to plot on
+
+		Returns:
+			ax (matplotlib axes): Axes with browser plot added
+		"""
+
+		# TODO option to plot relative to gene start or not
+
+		# set up axes if not provided
+		if not ax:
+			plt.figure(1, figsize=(4,3), frameon=False)
+			plt.xlim(x, x+w)
+			plt.ylim(y-2, y+2)
+			ax = plt.gca()
+
+		# change color
+		if not color:
+			color = self.color_dict['browser']
+
+		# get min / max coords from gene and transcript
+		g_min = self.g_min
+		g_max = self.g_max
+		t_min, t_max = self.get_transcript_min_max(self.tid)
+		g_len = g_max - g_min
+		t_len = t_max - t_min
+
+		# scaling factor
+		scale = w / g_len
+		self.scale = scale
+
+		# path / strand info
+		strand = self.strand
+		loc_path = self.loc_path
+		edge_path = self.edge_path
+
+		# plot exons
+		exons = [(self.loc_df.loc[v1, 'coord'],
+				 self.loc_df.loc[v2, 'coord']) \
+				 for v1,v2 in zip(loc_path[:-1],loc_path[1:])][::2]
+		y_coord = y
+		ax = self.plot_regions(exons, scale, strand, g_min, g_max,
+					           x, y, h, color, ax)
+
+		# plot intron as a line b/w first and last exons
+		dist = 125*scale
+		y_line = y + (h/2)
+		if strand == '+':
+			c1 = ((t_min-g_min)*scale)+x
+			c2 = c1+(t_len*scale)-dist
+			x_coords = [c1+dist, c2-dist]
+		elif strand == '-':
+			c1 = ((g_max-t_max)*scale)+x
+			c2 = c1+(t_len*scale)
+			x_coords = [c1+dist, c2-dist]
+
+		plt.plot(x_coords, [y_line,y_line], color=color,
+				 linewidth=linewidth, zorder=1)
+
+		return ax
+
 	# plots the browser track representation of the transcript from self.path
 	def plot_browser_path(self):
 
@@ -595,12 +847,6 @@ class PlottedGraph(Graph):
 			x_coord = scale_start - (gene_len/7)
 		ax.text(x_coord, y_coord, txt, fontsize=30)
 
-		# # check if forward or reverse strand
-		# if self.strand == '-':
-		#	 ordered_nodes.reverse()
-		#
-		# return ordered_nodes
-
 	# orders edges by those present in the transcript and those not present in the transcript
 	def get_ordered_edges(self):
 		self.edge_df['in_transcript'] = self.edge_df.apply(lambda x:
