@@ -1,3 +1,4 @@
+import pdb
 import networkx as nx
 import numpy as np
 import pandas as pd
@@ -9,6 +10,9 @@ import os
 import copy
 from collections import defaultdict
 from tqdm import tqdm
+import scanpy as sc
+from scipy import sparse
+
 from swan_vis.talon_utils import *
 
 pd.options.mode.chained_assignment = None
@@ -71,7 +75,7 @@ def make_uns_key(kind, obs_col, obs_conditions, die_kind='iso'):
 		obs_col (str): Column name from self.adata.obs table to group on.
 		obs_conditions (list of str, len 2): Which conditions from obs_col
 			to compare? Required if obs_col has more than 2 unique values.
-		die_kind (str): Which DIE test results. Choose from 'iso', 'tss', 'tes'
+		die_kind (str): Which DIE test results. {'iso', 'tss', 'tes', 'ic'}
 			Default: 'tss'
 
 	Returns:
@@ -276,8 +280,10 @@ def get_ends(t_df, kind):
 	Parameters:
 		kind (str): Choose 'tss' or 'tes'
 	"""
+	# might be able to use this in the future:
+	# https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.explode.html
 	if kind == 'tss':
-		ind = 1
+		ind = 0
 	elif kind == 'tes':
 		ind = -1
 
@@ -296,13 +302,15 @@ def pivot_path_list(t_df, path_col):
 		t_df (pandas DataFrame): Transcript datafram from SwanGraph
 		path_col (str): Which path to pull from. Choose from 'path' or 'loc_path'
 	"""
-	df = pd.DataFrame([[tid, x] for tid, path in zip(t_df.index, t_df[path_col]) \
-		for x in path])
+	df = t_df.explode(path_col, ignore_index=False)
 	if path_col == 'path':
-		df.columns = ['tid', 'edge_id']
+		c = 'edge_id'
+		c_map = {path_col: c}
 	elif path_col == 'loc_path':
-		df.columns = ['tid', 'vertex_id']
-	df.set_index('tid', inplace=True)
+		c = 'vertex_id'
+		c_map = {path_col: c}
+	df.rename(c_map, axis=1, inplace=True)
+	df = df[[c]]
 	return df
 
 ##########################################################################
@@ -326,14 +334,21 @@ def calc_total_counts(adata, obs_col='dataset', layer='counts'):
 			per condition.
 
 	"""
-	adata.X = adata.layers[layer]
-	df = pd.DataFrame(data=adata.X, index=adata.obs[obs_col].tolist(), \
-		columns=adata.var.index.tolist())
+
+	# turn into a sparse dataframe
+	cols = adata.var.index.tolist()
+	inds = adata.obs[obs_col].tolist()
+	data = adata.layers[layer].toarray()
+	df = pd.DataFrame(data=data, index=inds, columns=cols)
+	df.index.name = obs_col
 
 	# add up values on condition (row)
 	df = df.groupby(level=0).sum()
 
-	# df = df.transpose()
+	# convert to sparse
+	df = pd.DataFrame.sparse.from_spmatrix(data=sparse.csr_matrix(df.values),
+										   index=df.index.tolist(),
+										   columns=df.columns)
 
 	return df
 
@@ -365,6 +380,7 @@ def calc_pi(adata, t_df, obs_col='dataset'):
 	conditions = adata.obs[obs_col].unique().tolist()
 	df = calc_total_counts(adata, obs_col=obs_col)
 	df = df.transpose()
+
 	# we use ints to index edges and locs
 	if id_col == 'vertex_id' or id_col == 'edge_id':
 		df.index = df.index.astype('int')
@@ -375,58 +391,63 @@ def calc_pi(adata, t_df, obs_col='dataset'):
 
 	# add gid
 	df = df.merge(t_df['gid'], how='left', left_index=True, right_index=True)
+	t_counts = df.melt(id_vars=['gid'],
+					   value_vars=conditions,
+					   var_name=obs_col,
+					   value_name='t_counts',
+					   ignore_index=False)
+	t_counts.index.name = id_col
+	t_counts.reset_index(inplace=True)
 
 	# calculate total number of reads per gene per condition
 	temp = df.copy(deep=True)
 	temp.reset_index(drop=True, inplace=True)
+	temp[conditions] = temp[conditions].sparse.to_dense()
 	totals = temp.groupby('gid').sum().reset_index()
 
 	# merge back in
+	df = df.copy(deep=True)
 	df.reset_index(inplace=True)
 	df.rename({'index':id_col}, axis=1, inplace=True)
-	df = df.merge(totals, on='gid', suffixes=(None, '_total'))
+	df = df.merge(totals, on='gid', suffixes=('_t_counts', None))
 	del totals
 
-	# calculate percent iso exp for each gene / transcript / condition
-	pi_cols = []
-	for c in conditions:
-		cond_col = '{}_pi'.format(c)
-		total_col = '{}_total'.format(c)
-		df[cond_col] = (df[c]/df[total_col])*100
-		pi_cols.append(cond_col)
+	df = df.melt(id_vars=['gid'],
+				 value_vars=conditions,
+				 var_name=obs_col,
+				 value_name='gene_counts')
+	df = df.drop_duplicates()
+	df = t_counts.merge(df, how='left', on=['gid', obs_col])
 
-	# cleanup: fill nans with 0, set indices, rename cols
-	df.fillna(0, inplace=True)
+	df['pi'] = (df.t_counts/df.gene_counts)*100
+	df = df.pivot(columns=obs_col, index=id_col, values='pi')
 
-	# formatting
-	df.set_index(id_col, inplace=True)
-	df = df[pi_cols]
-	for col in pi_cols:
-		new_col = col[:-3]
-		df.rename({col: new_col}, axis=1, inplace=True)
+	# order based on order in adata
+	ids = adata.var.index.tolist()
+	df = df.loc[ids]
+	cols = adata.obs[obs_col].unique().tolist()
+	df = df[cols]
 
-	# reorder columns like adata.obs
-	df = df[adata.obs[obs_col].unique().tolist()]
+	# convert to sparse
 	df = df.transpose()
-	# df.index.name = obs_col # maybe put this back in ?
-
-	# reorder in adata.var / t_df order
-	if id_col != 'tss_id' and id_col != 'tes_id':
-		df = df[t_df[id_col].tolist()]
-
+	df = pd.DataFrame.sparse.from_spmatrix(data=sparse.csr_matrix(df.values),
+										   index=df.index.tolist(),
+										   columns=df.columns)
 	return df, sums
 
-def calc_tpm(adata, sg_df=None, obs_col='dataset'):
+def calc_tpm(adata, obs_col='dataset', how='mean', recalc=False):
 	"""
 	Calculate the TPM per condition given by `obs_col`.
 	Default column to use is `adata.obs` index column, `dataset`.
 
 	Parameters:
 		adata (anndata AnnData): Annotated data object from the SwanGraph
-		sg_df (pandas DataFrame): Pandas DataFrame from SwanGraph that will
-			be used to order the rows of resultant TPM DataFrame
 		obs_col (str or list of str): Column name from adata.obs table to group on.
 			Default: 'dataset'
+		how (str): How to compute tpm across multiple datasets {'mean', 'max'}
+		recalc (bool): Whether tpm data should be recalculated or tpm
+			values should just be averaged
+			Default: False
 
 	Returns:
 		df (pandas DataFrame): Pandas datafrom where rows are the different
@@ -435,39 +456,51 @@ def calc_tpm(adata, sg_df=None, obs_col='dataset'):
 			condition.
 	"""
 
-	# calculate cumulative counts across obs_col
-	id_col = adata.var.index.name
-	conditions = adata.obs[obs_col].unique().tolist()
-	df = calc_total_counts(adata, obs_col=obs_col)
-	df = df.transpose()
+	# only need to calculate tpm once when adding abundance
+	if recalc:
 
-	# we use ints to index edges and locs
-	if id_col == 'vertex_id' or id_col == 'edge_id':
-		df.index = df.index.astype('int')
+		# calculate tpm using scanpy
+		d = sc.pp.normalize_total(adata,
+								  layer='counts',
+								  target_sum=1e6,
+								  key_added='total_counts',
+								  inplace=False)
+		adata.obs['total_counts'] = d['norm_factor']
+		data = d['X'].toarray()
 
-	# calculate tpm per isoform per condition
-	tpm_cols = []
-	for c in conditions:
-		cond_col = '{}_tpm'.format(c)
-		total_col = '{}_total'.format(c)
-		df[total_col] = df[c].sum()
-		df[cond_col] = (df[c]*1000000)/df[total_col]
-		tpm_cols.append(cond_col)
+	# otherwise just grab the tpm from the adata
+	else:
+		data = adata.layers['tpm'].toarray()
 
-	# formatting
-	df.index.name = id_col
-	df = df[tpm_cols]
-	for col in tpm_cols:
-		new_col = col[:-4]
-		df.rename({col: new_col}, axis=1, inplace=True)
+	# turn into a dataframe
+	cols = adata.var.index.tolist()
+	inds = adata.obs[obs_col].tolist()
+	df = pd.DataFrame(data=data, columns=cols, index=inds)
+	df.index.name = obs_col
 
-	# reorder columns like adata.obs
-	df = df[adata.obs[obs_col].unique().tolist()]
-	df = df.transpose()
+	# average across tpm
+	if obs_col != 'dataset':
 
-	# reorder in adata.var / t_df order
-	if not isinstance(sg_df, type(None)):
-		df = df[sg_df[id_col].tolist()]
+		# keep track of original row order to sort by
+		row_order = df.index.unique().tolist()
+		row_map = {}
+		for i, row in enumerate(row_order):
+			row_map[row] = i
+
+		df['row_order'] = df.index.map(row_map)
+		df.reset_index(inplace=True)
+		if how == 'mean':
+			df = df.groupby(obs_col).mean()
+		elif how == 'max':
+			df = df.groupby(obs_col).max()
+		df = df.sort_values(by='row_order', ascending=True)
+		df.drop('row_order', inplace=True, axis=1)
+
+	# make sparse
+	data = sparse.csr_matrix(df.values)
+	inds = df.index.tolist()
+	cols = df.columns.tolist()
+	df = pd.DataFrame.sparse.from_spmatrix(data, index=inds, columns=cols)
 
 	return df
 
@@ -475,6 +508,30 @@ def calc_tpm(adata, sg_df=None, obs_col='dataset'):
 ####################### Related to file parsing ##########################
 ##########################################################################
 
+def get_stable_gid(df, col):
+	"""
+	Get a list of stable gene ids from a dataframe
+
+	Parameters:
+		df (pandas DataFrame): DF w/ ENSEMBL gids in some column
+		col (str): Column name of gids
+
+	Returns:
+		gids (list of str): List of stable gids
+	"""
+	df = df.copy(deep=True)
+	try:
+		df[['temp', 'par_region_1', 'par_region_2']] = df[col].str.split('_', n=2, expand=True)
+		df[col] = df[col].str.split('.', expand=True)[0]
+		df[['par_region_1', 'par_region_2']] = df[['par_region_1',
+														   'par_region_2']].fillna('')
+		df[col] = df[col]+df.par_region_1+df.par_region_2
+		df.drop(['temp', 'par_region_1', 'par_region_2'], axis=1, inplace=True)
+	except:
+		df[col] = df[col].str.split('.', expand=True)[0]
+
+	return df[col].tolist()
+
 def parse_db(database, pass_list, observed, include_isms, verbose):
 	"""
 	Get the unique transcripts and exons that are present in a TALON DB
@@ -569,6 +626,7 @@ def parse_db(database, pass_list, observed, include_isms, verbose):
 			gid = gene_annotation_dict['gene_id']
 			gname = gene_annotation_dict['gene_name']
 			strand = transcript_entry['strand']
+
 			novelty = get_transcript_novelties(transcript_annotation_dict)
 
 			# add transcript to dictionary
@@ -626,6 +684,13 @@ def parse_db(database, pass_list, observed, include_isms, verbose):
 
 	t_df = pd.DataFrame(transcripts).transpose()
 	exon_df = pd.DataFrame(exons).transpose()
+
+	# use stable gid if we can
+	try:
+		t_df['gid'] = get_stable_gid(t_df, 'gid')
+	except:
+		pass
+
 	return t_df, exon_df
 
 def parse_gtf(gtf_file, include_isms, verbose):
@@ -649,6 +714,7 @@ def parse_gtf(gtf_file, include_isms, verbose):
 			(all exon in this case) of each exon.
 		from_talon (bool): Whether or not the GTF was determined to be
 			from TALON
+		from_cerberus (bool): Whether or not the GTF is from cerberus
 	"""
 
 	# counts the number of transcripts in a given GTF
@@ -667,6 +733,7 @@ def parse_gtf(gtf_file, include_isms, verbose):
 	transcripts = {}
 	exons = {}
 	from_talon = False
+	from_cerberus = False
 	ism_tids = []
 
 	# display progess
@@ -707,8 +774,10 @@ def parse_gtf(gtf_file, include_isms, verbose):
 				# check if this gtf has transcript novelty vals
 				# for the first transcript entry
 				if not transcripts:
-					if 'talon_transcript' in attributes:
+					if 'talon_transcript' in attributes or 'talon_gene' in attributes:
 						from_talon = True
+					if 'ic_id' in attributes:
+						from_cerberus = True
 
 				tid = attributes['transcript_id']
 				gid = attributes['gene_id']
@@ -735,6 +804,10 @@ def parse_gtf(gtf_file, include_isms, verbose):
 				if from_talon:
 					novelty = get_transcript_novelties(attributes)
 					entry['novelty'] = novelty
+				if from_cerberus:
+					entry['tss_id'] = attributes['tss_id']
+					entry['tes_id'] = attributes['tes_id']
+					entry['ic_id'] = attributes['ic_id']
 
 				# do not include ISM transcripts
 				if not include_isms and from_talon:
@@ -782,7 +855,13 @@ def parse_gtf(gtf_file, include_isms, verbose):
 	if not include_isms:
 		t_df = t_df.loc[~t_df.tid.isin(ism_tids)]
 
-	return t_df, exon_df, from_talon
+	# use stable gid if we can
+	try:
+		t_df['gid'] = get_stable_gid(t_df, 'gid')
+	except:
+		pass
+
+	return t_df, exon_df, from_talon, from_cerberus
 
 ##########################################################################
 ######################## Related to DIE testing ##########################
@@ -807,7 +886,7 @@ def get_die_gene_table(gene_df, conditions, rc):
 		gene_df (pandas DataFrame): :ength n table of counts per isoform per
 			condition, percent isoform per gene per condition, and change in
 			percent isoform across conditions IF the gene is testable
-		gene_df (None): Returns None if the gene was deemed untestable.
+		test_result (str): Reason why gene was untestable, if relevant
 	"""
 
 	id_col = 'tid'
@@ -820,7 +899,8 @@ def get_die_gene_table(gene_df, conditions, rc):
 
 	# limit to genes with more than 1 isoform expressed
 	if len(gene_df.index) <= 1:
-		return None
+		test_result = '1_iso'
+		return None, test_result
 
 	# if there are more than 11 isoforms, agg. the n - 11 least expressed
 	# isoforms into one
@@ -835,21 +915,29 @@ def get_die_gene_table(gene_df, conditions, rc):
 
 		gene_df = gene_df.iloc[:10]
 		gene_df = pd.concat([gene_df, temp])
+		gene_df.set_index('tid', inplace=True)
 
 	# does this gene reach the desired read count threshold?
 	for cond in conditions:
 		counts_col = cond+'_counts'
 		if gene_df[counts_col].sum() < rc:
-			return None
+			test_result = 'below_rc'
+			return None, test_result
 
 	# only do the rest if there's something left
 	if gene_df.empty:
-		return None
+		test_result = 'both_0_exp'
+		return None, test_result
 
 	# compute isoform-level and gene-level delta pis
+	# gene_df[cond1] = gene_df[cond1].astype(float)
+	# gene_df[cond2] = gene_df[cond2].astype(float)
+	gene_df[cond1] = gene_df[cond1].values.to_dense().astype(np.float64)
+	gene_df[cond2] = gene_df[cond2].values.to_dense().astype(np.float64)
 	gene_df['dpi'] = gene_df[cond1] - gene_df[cond2]
+	test_result = 'testable'
 
-	return gene_df
+	return gene_df, test_result
 
 def test_gene(gene_df, conditions):
 	"""
@@ -863,8 +951,8 @@ def test_gene(gene_df, conditions):
 		conditions (list of str, len 2): Name of condition columns
 
 	Returns:
-		p (float): P-value result of chi-squared test on gene
-		dpi (float): Overall change in isoform expression
+		entry (list): List of gene id, gene dpi, and information about top 2 pos
+			and neg dpis
 	"""
 
 	counts_cols = [c+'_counts' for c in conditions]
@@ -874,20 +962,30 @@ def test_gene(gene_df, conditions):
 	temp = temp.loc[temp.dpi > 0]
 
 	# if there are fewer than 2 isoforms
-	if len(temp.index) >= 2:
+	temp_len = len(temp.index)
+	if temp_len >= 2:
 		pos_dpi = temp.iloc[:2].dpi.sum(axis=0)
+		pos_isos = temp.iloc[:2].index.tolist()
+		pos_dpis = temp.iloc[:2].dpi.tolist()
 	else:
 		pos_dpi = temp.dpi.sum(axis=0)
+		pos_isos = temp.index.tolist()+[np.nan for i in range(temp_len, 2)]
+		pos_dpis = temp.dpi.tolist()+[np.nan for i in range(temp_len, 2)]
 
 	# get highest 2 negative dpis
 	temp = gene_df.sort_values(by='dpi', ascending=True)
 	temp = temp.loc[temp.dpi < 0]
 
 	# if there are fewer than 2 isoforms
-	if len(temp.index) >= 2:
+	temp_len = len(temp.index)
+	if temp_len >= 2:
 		neg_dpi = abs(temp.iloc[:2].dpi.sum(axis=0))
+		neg_isos = temp.iloc[:2].index.tolist()
+		neg_dpis = temp.iloc[:2].dpi.tolist()
 	else:
 		neg_dpi = abs(temp.dpi.sum(axis=0))
+		neg_isos = temp.index.tolist()+[np.nan for i in range(temp_len, 2)]
+		neg_dpis = temp.dpi.tolist()+[np.nan for i in range(temp_len, 2)]
 
 	gene_dpi = max(pos_dpi, neg_dpi)
 
@@ -895,7 +993,9 @@ def test_gene(gene_df, conditions):
 	chi_table = gene_df[counts_cols].to_numpy()
 	chi2, p, dof, exp = st.chi2_contingency(chi_table)
 
-	return p, gene_dpi
+	entry = [p, gene_dpi]+pos_isos+pos_dpis+neg_isos+neg_dpis
+
+	return entry
 
 # turn a list of dataset groups and names for those groups into a
 # dictionary
@@ -911,9 +1011,11 @@ def make_cond_map(groups, group_names):
 
 # get novelty types associated with each transcript
 def get_transcript_novelties(fields):
-	if fields['transcript_status'] == 'KNOWN':
-		return 'Known'
-	elif 'ISM_transcript' in fields:
+	if 'transcript_status' in fields.keys():
+		if fields['transcript_status'] == 'KNOWN':
+			return 'Known'
+
+	if 'ISM_transcript' in fields:
 		return 'ISM'
 	elif 'NIC_transcript' in fields:
 		return 'NIC'
@@ -925,15 +1027,17 @@ def get_transcript_novelties(fields):
 		return 'Intergenic'
 	elif 'genomic_transcript' in fields:
 		return 'Genomic'
+	else:
+		return 'Undefined'
 
 # reformat talon abundance file for the generic format expected by swan
-def reformat_talon_abundance(fname, ofile=None):
+def reformat_talon_abundance(df, how='iso', ofile=None):
 	"""
 	Reformat TALON abundance file into the format expected by add_abundance.
 	Removes all columns but the annot_transcript_id column and counts columns.
 
 	Parameters:
-		fname (str): Name / path to TALON abundance file
+		df (pandas DataFrame): DF representation of TALON abundance
 		ofile (str): Filename to save output to, if any.
 			Default: None
 
@@ -941,13 +1045,21 @@ def reformat_talon_abundance(fname, ofile=None):
 		df (pandas DataFrame): DataFrame of abundance values indexed by
 			transcript ID
 	"""
-	check_file_loc(fname, 'TALON abundance')
 
-	df = pd.read_csv(fname, sep='\t')
-	drop_cols = ['gene_ID', 'transcript_ID', 'annot_gene_id', 'annot_gene_name',
+	drop_cols = ['gene_ID', 'transcript_ID', 'annot_gene_name',
 		'annot_transcript_name', 'n_exons', 'length', 'gene_novelty',
 		'transcript_novelty', 'ISM_subtype']
-	df.drop(drop_cols, axis=1, inplace=True)
+	if how=='iso':
+		drop_cols.append('annot_gene_id')
+	elif how=='gene':
+		drop_cols.append('annot_transcript_id')
+
+	# drop the drop cols that exist in this df
+	# (ignore key errors)
+	df.drop(drop_cols,
+			axis=1,
+			inplace=True,
+			errors='ignore')
 
 	# if not writing output file just return df
 	if not ofile:
